@@ -1,4 +1,3 @@
-#
 #===============================================================================
 #
 #         FILE:  Wizarded.pm
@@ -9,10 +8,7 @@
 #         BUGS:  ---
 #        NOTES:  ---
 #       AUTHOR:  Pavel Boldin (), <davinchi@cpan.ru>
-#      COMPANY:  
-#      VERSION:  1.0
 #      CREATED:  25.06.2008 14:20:31 MSD
-#     REVISION:  ---
 #===============================================================================
 
 package CatalystX::Wizarded;
@@ -21,7 +17,7 @@ use strict;
 use warnings;
 
 require Catalyst::Controller;
-
+require Catalyst::ActionChain;
 
 sub wizard {
     my $c = shift;
@@ -38,6 +34,11 @@ sub import {
     my $action_class = shift || 'Catalyst::Action::Wizard';
     Catalyst::Controller->_action_class($action_class);
 
+#    use Data::Dumper;
+#    warn Dumper \@Catalyst::ActionChain::ISA;
+    s/^Catalyst::Action$/$action_class/ foreach @Catalyst::ActionChain::ISA;
+#    warn Dumper \@Catalyst::ActionChain::ISA;
+
     my %defaults = (
 	expires	    => 86400,
 	instance    => 'Catalyst::Wizard',
